# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.ui.dialogs.address_book_source_pilot import AddressBookSourcePilot as AddressBookSourcePilot
from ....lo.ui.dialogs.common_file_picker_element_ids import CommonFilePickerElementIds as CommonFilePickerElementIds
from ....lo.ui.dialogs.control_actions import ControlActions as ControlActions
from ....lo.ui.dialogs.dialog_closed_event import DialogClosedEvent as DialogClosedEvent
from ....lo.ui.dialogs.executable_dialog_exception import ExecutableDialogException as ExecutableDialogException
from ....lo.ui.dialogs.executable_dialog_results import ExecutableDialogResults as ExecutableDialogResults
from ....lo.ui.dialogs.extended_file_picker_element_ids import ExtendedFilePickerElementIds as ExtendedFilePickerElementIds
from ....lo.ui.dialogs.file_picker import FilePicker as FilePicker
from ....lo.ui.dialogs.file_picker_event import FilePickerEvent as FilePickerEvent
from ....lo.ui.dialogs.file_preview_image_formats import FilePreviewImageFormats as FilePreviewImageFormats
from ....lo.ui.dialogs.filter_options_dialog import FilterOptionsDialog as FilterOptionsDialog
from ....lo.ui.dialogs.folder_picker import FolderPicker as FolderPicker
from ....lo.ui.dialogs.listbox_control_actions import ListboxControlActions as ListboxControlActions
from ....lo.ui.dialogs.template_description import TemplateDescription as TemplateDescription
from ....lo.ui.dialogs.wizard import Wizard as Wizard
from ....lo.ui.dialogs.wizard_button import WizardButton as WizardButton
from ....lo.ui.dialogs.wizard_travel_type import WizardTravelType as WizardTravelType
from ....lo.ui.dialogs.x_asynchronous_executable_dialog import XAsynchronousExecutableDialog as XAsynchronousExecutableDialog
from ....lo.ui.dialogs.x_control_access import XControlAccess as XControlAccess
from ....lo.ui.dialogs.x_control_information import XControlInformation as XControlInformation
from ....lo.ui.dialogs.x_dialog_closed_listener import XDialogClosedListener as XDialogClosedListener
from ....lo.ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog
from ....lo.ui.dialogs.x_file_picker import XFilePicker as XFilePicker
from ....lo.ui.dialogs.x_file_picker2 import XFilePicker2 as XFilePicker2
from ....lo.ui.dialogs.x_file_picker3 import XFilePicker3 as XFilePicker3
from ....lo.ui.dialogs.x_file_picker_control_access import XFilePickerControlAccess as XFilePickerControlAccess
from ....lo.ui.dialogs.x_file_picker_listener import XFilePickerListener as XFilePickerListener
from ....lo.ui.dialogs.x_file_picker_notifier import XFilePickerNotifier as XFilePickerNotifier
from ....lo.ui.dialogs.x_file_preview import XFilePreview as XFilePreview
from ....lo.ui.dialogs.x_filter_group_manager import XFilterGroupManager as XFilterGroupManager
from ....lo.ui.dialogs.x_filter_manager import XFilterManager as XFilterManager
from ....lo.ui.dialogs.x_folder_picker import XFolderPicker as XFolderPicker
from ....lo.ui.dialogs.x_folder_picker2 import XFolderPicker2 as XFolderPicker2
from ....lo.ui.dialogs.xslt_filter_dialog import XSLTFilterDialog as XSLTFilterDialog
from ....lo.ui.dialogs.x_wizard import XWizard as XWizard
from ....lo.ui.dialogs.x_wizard_controller import XWizardController as XWizardController
from ....lo.ui.dialogs.x_wizard_page import XWizardPage as XWizardPage



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uno
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_adapter import XAdapter as XAdapter_7a4e0973

class XWeak(XInterface_8f010a43):
    """
    the server-side interface to a weak object.
    
    This interface is proxy to the adapted object. In order to make it possible to have weak references to objects, the XAdapter interface must be implemented to provide a weak adapter for the clients.
    
    This module specifies the interfaces for implementing and using weak references.
    
    The sense of weak references is to hold a reference to an object without affecting the lifetime of the object. That means that a weak reference may become invalid, at any time, if the referenced object dies.
    
    The following interfaces describe one way to handle weak references by providing a weak adapter. The weak object has to provide this adapter if anyone wants to hold a weak reference. To separate their lifetimes, the adapter and the original object must not share the same reference counter. The weak reference is in fact only a hard reference to the adapter, which knows - but does not hold - the original object. That means that the implementation and synchronization of weak referencing is the responsibility of the object. The following interfaces are involved in the concept of weak referencing:

    See Also:
        `API XWeak <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XWeak.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uno'
    __ooo_full_ns__: str = 'com.sun.star.uno.XWeak'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uno.XWeak'

    @abstractmethod
    def queryAdapter(self) -> XAdapter_7a4e0973:
        """
        queries the weak adapter.
        
        It is important that the adapter must know, but not hold the adapted object. If the adapted object dies, all references to the adapter have to be notified to release the adapter.
        """
        ...

__all__ = ['XWeak']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XMultipleResults(XInterface_8f010a43):
    """
    is used for inspecting multiple results produced by the execution of a SQL statement.
    
    Under some (uncommon) situations a single SQL statement may return multiple result sets and/or update counts. Normally you can ignore this unless you are (1) executing a stored procedure that you know may return multiple results or (2) you are dynamically executing an unknown SQL string. The methods com.sun.star.sdbc.XMultipleResults.getMoreResults() , com.sun.star.sdbc.XMultipleResults.getResultSet() and com.sun.star.sdbc.XMultipleResults.getUpdateCount() let you navigate through multiple results.

    See Also:
        `API XMultipleResults <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XMultipleResults.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XMultipleResults'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XMultipleResults'

    @abstractmethod
    def getMoreResults(self) -> bool:
        """
        moves to a Statement's next result.
        
        It returns TRUE if this result is a ResultSet. This method also implicitly closes any current ResultSet obtained with getResultSet.
        
        There are no more results when (!getMoreResults() &amp;&amp; getUpdateCount() == -1).

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getResultSet(self) -> XResultSet_98e30aa7:
        """
        returns the current result as a com.sun.star.sdbc.ResultSet object.
        
        This method should be called only once per result.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getUpdateCount(self) -> int:
        """
        returns the current result as an update count.
        
        If the result is a ResultSet or there are no more results, -1 is returned. This method should be called only once per result.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XMultipleResults']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2.data
from __future__ import annotations
import typing
import uno
from abc import abstractproperty
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_data_sequence import XDataSequence as XDataSequence_11f00e1f
from .x_numerical_data_sequence import XNumericalDataSequence as XNumericalDataSequence_a43011bf
from .x_textual_data_sequence import XTextualDataSequence as XTextualDataSequence_82171106
from ...container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
from ...util.x_cloneable import XCloneable as XCloneable_99d00aa3
from ...util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from .data_sequence_role import DataSequenceRole as DataSequenceRole_3f520f59

class DataSequence(XPropertySet_bc180bfa, XDataSequence_11f00e1f, XNumericalDataSequence_a43011bf, XTextualDataSequence_82171106, XIndexReplace_feed0dd7, XCloneable_99d00aa3, XModifyBroadcaster_fd990df0):
    """
    Service Class

    describes a container for a sequence of values.
    
    With the interface XDataSequence it is possible to transfer a complete sequence of values.
    
    With the optional com.sun.star.container.XIndexReplace it is possible to modify single elements, if the corresponding DataProvider supports modification of its values.

    See Also:
        `API DataSequence <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1DataSequence.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.DataSequence'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HiddenValues(self) -> uno.ByteSequence:
        """
        a sequence of indexes that identify values that are hidden in the underlying data provider.
        """
        ...

    @abstractproperty
    def IncludeHiddenCells(self) -> bool:
        """
        If set to false FALSE, values from hidden cells are not returned.
        """
        ...

    @abstractproperty
    def Role(self) -> DataSequenceRole_3f520f59:
        """
        The key (index) of the number format that this sequence should be formatted with.
        
        The key identifies a number format in an com.sun.star.util.XNumberFormats object. This object can be retrieved by the com.sun.star.util.XNumberFormatsSupplier interface supported by com.sun.star.chart.ChartDocument.
        
        The role of the series inside a data series. This may be any string. However some strings are predefined and should always be used in the same way.
        """
        ...


__all__ = ['DataSequence']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1
if typing.TYPE_CHECKING:
    from .x_interface_type_description import XInterfaceTypeDescription as XInterfaceTypeDescription_d92e1342
    from .x_property_type_description import XPropertyTypeDescription as XPropertyTypeDescription_ca171316

class XServiceTypeDescription(XTypeDescription_3c210fb1):
    """
    Reflects a service.
    
    This type is superseded by XServiceTypeDescription2, which supports single-interface–based services, in addition to the obsolete, accumulation-based services.
    
    The type class of this type is com.sun.star.uno.TypeClass.SERVICE.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XServiceTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XServiceTypeDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XServiceTypeDescription'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XServiceTypeDescription'

    @abstractmethod
    def getMandatoryInterfaces(self) -> typing.Tuple[XInterfaceTypeDescription_d92e1342, ...]:
        """
        Returns the type descriptions of the mandatory interfaces defined for this service.
        """
        ...
    @abstractmethod
    def getMandatoryServices(self) -> typing.Tuple[XServiceTypeDescription, ...]:
        """
        Returns the type descriptions of the mandatory services defined for this service.
        """
        ...
    @abstractmethod
    def getOptionalInterfaces(self) -> typing.Tuple[XInterfaceTypeDescription_d92e1342, ...]:
        """
        Returns the type descriptions of the optional interface defined for this service.
        """
        ...
    @abstractmethod
    def getOptionalServices(self) -> typing.Tuple[XServiceTypeDescription, ...]:
        """
        Returns the type descriptions of the optional services defined for this service.
        """
        ...
    @abstractmethod
    def getProperties(self) -> typing.Tuple[XPropertyTypeDescription_ca171316, ...]:
        """
        Returns the properties defined for this service.
        """
        ...

__all__ = ['XServiceTypeDescription']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2.data
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class PivotTableFieldEntry(object):
    """
    Struct Class

    Pivot table field entry data.
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API PivotTableFieldEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1data_1_1PivotTableFieldEntry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.PivotTableFieldEntry'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.data.PivotTableFieldEntry'
    """Literal Constant ``com.sun.star.chart2.data.PivotTableFieldEntry``"""

    def __init__(self, Name: typing.Optional[str] = '', DimensionIndex: typing.Optional[int] = 0, DimensionPositionIndex: typing.Optional[int] = 0, HasHiddenMembers: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            DimensionIndex (int, optional): DimensionIndex value.
            DimensionPositionIndex (int, optional): DimensionPositionIndex value.
            HasHiddenMembers (bool, optional): HasHiddenMembers value.
        """
        super().__init__()

        if isinstance(Name, PivotTableFieldEntry):
            oth: PivotTableFieldEntry = Name
            self.Name = oth.Name
            self.DimensionIndex = oth.DimensionIndex
            self.DimensionPositionIndex = oth.DimensionPositionIndex
            self.HasHiddenMembers = oth.HasHiddenMembers
            return

        kargs = {
            "Name": Name,
            "DimensionIndex": DimensionIndex,
            "DimensionPositionIndex": DimensionPositionIndex,
            "HasHiddenMembers": HasHiddenMembers,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._dimension_index = kwargs["DimensionIndex"]
        self._dimension_position_index = kwargs["DimensionPositionIndex"]
        self._has_hidden_members = kwargs["HasHiddenMembers"]


    @property
    def Name(self) -> str:
        """
        Name of the field entry.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def DimensionIndex(self) -> int:
        """
        The index of the field entry.
        """
        return self._dimension_index

    @DimensionIndex.setter
    def DimensionIndex(self, value: int) -> None:
        self._dimension_index = value

    @property
    def DimensionPositionIndex(self) -> int:
        """
        The output position of the field entry in its field type.
        """
        return self._dimension_position_index

    @DimensionPositionIndex.setter
    def DimensionPositionIndex(self, value: int) -> None:
        self._dimension_position_index = value

    @property
    def HasHiddenMembers(self) -> bool:
        """
        Does it have some members that are hidden (filtered).
        """
        return self._has_hidden_members

    @HasHiddenMembers.setter
    def HasHiddenMembers(self, value: bool) -> None:
        self._has_hidden_members = value


__all__ = ['PivotTableFieldEntry']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class Alignment(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.Alignment", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.Alignment`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.Alignment import BOTTOM as ALIGNMENT_BOTTOM
        from com.sun.star.drawing.Alignment import BOTTOM_LEFT as ALIGNMENT_BOTTOM_LEFT
        from com.sun.star.drawing.Alignment import BOTTOM_RIGHT as ALIGNMENT_BOTTOM_RIGHT
        from com.sun.star.drawing.Alignment import CENTER as ALIGNMENT_CENTER
        from com.sun.star.drawing.Alignment import LEFT as ALIGNMENT_LEFT
        from com.sun.star.drawing.Alignment import RIGHT as ALIGNMENT_RIGHT
        from com.sun.star.drawing.Alignment import TOP as ALIGNMENT_TOP
        from com.sun.star.drawing.Alignment import TOP_LEFT as ALIGNMENT_TOP_LEFT
        from com.sun.star.drawing.Alignment import TOP_RIGHT as ALIGNMENT_TOP_RIGHT

        class Alignment(uno.Enum):
            """
            Enum Class


            See Also:
                `API Alignment <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.Alignment', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.Alignment'
            __ooo_type_name__: str = 'enum'

            BOTTOM = ALIGNMENT_BOTTOM
            """
            the connection line leaves the connected object from the bottom,

            The text is positioned below the main line.

            The bottom edge of the text is adjusted to the bottom edge of the shape.
            """
            BOTTOM_LEFT = ALIGNMENT_BOTTOM_LEFT
            """
            """
            BOTTOM_RIGHT = ALIGNMENT_BOTTOM_RIGHT
            """
            """
            CENTER = ALIGNMENT_CENTER
            """
            The text is centered inside the shape.
            """
            LEFT = ALIGNMENT_LEFT
            """
            the connection line leaves the connected object to the left,

            The left edge of the text is adjusted to the left edge of the shape.

            The text is positioned to the left.
            """
            RIGHT = ALIGNMENT_RIGHT
            """
            the connection line leaves the connected object to the right,

            The right edge of the text is adjusted to the right edge of the shape.

            The text is positioned to the right.
            """
            TOP = ALIGNMENT_TOP
            """
            the connection line leaves the connected object from the top,

            The text is positioned above the main line.

            The top edge of the text is adjusted to the top edge of the shape.
            """
            TOP_LEFT = ALIGNMENT_TOP_LEFT
            """
            """
            TOP_RIGHT = ALIGNMENT_TOP_RIGHT
            """
            """
    else:
        # keep document generators happy
        from ...lo.drawing.alignment import Alignment as Alignment


__all__ = ['Alignment']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XUsedAreaCursor(XInterface_8f010a43):
    """
    provides methods to find the used area of the entire sheet.
    
    The used area is the smallest cell range that contains all cells of the spreadsheet with any contents (values, text, formulas) or visible formatting (borders and background color).

    See Also:
        `API XUsedAreaCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XUsedAreaCursor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XUsedAreaCursor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XUsedAreaCursor'

    @abstractmethod
    def gotoEndOfUsedArea(self, bExpand: bool) -> None:
        """
        points the cursor to the end of the used area.
        """
        ...
    @abstractmethod
    def gotoStartOfUsedArea(self, bExpand: bool) -> None:
        """
        points the cursor to the start of the used area.
        """
        ...

__all__ = ['XUsedAreaCursor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .chart_series_address import ChartSeriesAddress as ChartSeriesAddress_a480e3d

class ChartTableAddressSupplier(ABC):
    """
    Service Class

    This is a helper service for access to table Address to cell ranges of the container document of a chart.
    
    The cell addresses are in the format of the application that contains this chart.

    See Also:
        `API ChartTableAddressSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartTableAddressSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartTableAddressSupplier'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SeriesAddresses(self) -> typing.Tuple[ChartSeriesAddress_a480e3d, ...]:
        """
        contains the addresses to the elements of a series.
        
        This sequence should contain one element for each series in the chart.
        """
        ...

    @abstractproperty
    def CategoriesRangeAddress(self) -> str:
        """
        contains the address to the cells containing the names of the categories.
        
        Note: Each value of a data series belongs exactly to one category.
        """
        ...

    @abstractproperty
    def MainTitleAddress(self) -> str:
        """
        contains the address to the main title.
        """
        ...

    @abstractproperty
    def SubTitleAddress(self) -> str:
        """
        contains the address to the sub title.
        """
        ...


__all__ = ['ChartTableAddressSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_interface_attribute_type_description import XInterfaceAttributeTypeDescription as XInterfaceAttributeTypeDescription_98c716f6
if typing.TYPE_CHECKING:
    from .x_compound_type_description import XCompoundTypeDescription as XCompoundTypeDescription_c7be12f6

class XInterfaceAttributeTypeDescription2(XInterfaceAttributeTypeDescription_98c716f6):
    """
    Reflects an interface attribute, supporting extended attributes that are bound or raise exceptions.
    
    This type supersedes XInterfaceAttributeTypeDescription, which does not support extended attributes.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XInterfaceAttributeTypeDescription2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XInterfaceAttributeTypeDescription2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XInterfaceAttributeTypeDescription2'

    @abstractmethod
    def getGetExceptions(self) -> typing.Tuple[XCompoundTypeDescription_c7be12f6, ...]:
        """
        Returns the exceptions that can be raised by the attribute's getter.
        """
        ...
    @abstractmethod
    def getSetExceptions(self) -> typing.Tuple[XCompoundTypeDescription_c7be12f6, ...]:
        """
        Returns the exceptions that can be raised by the attribute's setter.
        """
        ...
    @abstractmethod
    def isBound(self) -> bool:
        """
        Returns whether this object reflects a bound attribute.
        """
        ...

__all__ = ['XInterfaceAttributeTypeDescription2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates_2a3e0f4d
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_style import XStyle as XStyle_7c7f09a2
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class Style(UserDefinedAttributesSupplier_9fbe1222, XMultiPropertySet_fd880e05, XMultiPropertyStates_2a3e0f4d, XPropertySet_bc180bfa, XStyle_7c7f09a2):
    """
    Service Class

    This service specifies a single style sheet.
    
    **since**
    
        OOo 2.0.1

    See Also:
        `API Style <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1Style.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.Style'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ParaStyleConditions(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        defines the context and styles for conditional paragraphs.
        
        This property is only available if the style is a conditional paragraph style.
        
        The sequence consists of pairs where the name part of the pair defines the context where it should be applied and the value part is a string naming the style to be used in that context.
        
        Assigning an empty string to the style name will disable the conditional style for that context.
        
        The allowed strings (contexts) for the name part of an entry of the sequence are:
        
        **since**
        
            OOo 2.0.1
        """
        ...

    @abstractproperty
    def StyleInteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of style properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def DisplayName(self) -> str:
        """
        contains the name of the style as it is displayed in the user interface.
        
        The names of the styles at the API are language independent. The user interface names are localized.
        """
        ...

    @abstractproperty
    def FollowStyle(self) -> str:
        """
        contains the name of the style that is applied to the next paragraph.
        
        This property is usually available at paragraph styles only.
        """
        ...

    @abstractproperty
    def Hidden(self) -> bool:
        """
        Flag indicating whether to hide the style in the UI.
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def IsAutoUpdate(self) -> str:
        """
        determines if a style is automatically updated, if the properties of an object that the style is applied to are changed.
        
        For example, if the style is applied to a paragraph and the properties of the paragraph are changed then the style will be updated accordingly.
        """
        ...

    @abstractproperty
    def IsPhysical(self) -> bool:
        """
        determines if a style is physically created.
        
        Built in styles may not be created until they are needed. To prevent standard style properties from being exported, it may be useful to check if the style is created first.
        """
        ...


__all__ = ['Style']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ui.ContextMenuInterceptorAction import ContextMenuInterceptorActionProto

class ContextMenuInterceptorAction(Enum):
    """
    Enum Class


    See Also:
        `API ContextMenuInterceptorAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui.html#a6e0452a8960be949dce52c427920ebbe>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ContextMenuInterceptorAction'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ui.ContextMenuInterceptorAction'

    CANCELLED = cast("ContextMenuInterceptorActionProto", 'CANCELLED')
    """
    the context menu must not be executed.
    
    The next registered XContextMenuInterceptor should not be notified.
    """
    CONTINUE_MODIFIED = cast("ContextMenuInterceptorActionProto", 'CONTINUE_MODIFIED')
    """
    the menu has been modified and the next registered XContextMenuInterceptor should be notified.
    """
    EXECUTE_MODIFIED = cast("ContextMenuInterceptorActionProto", 'EXECUTE_MODIFIED')
    """
    the menu has been modified and should be executed without notifying the next registered XContextMenuInterceptor.
    """
    IGNORED = cast("ContextMenuInterceptorActionProto", 'IGNORED')
    """
    the XContextMenuInterceptor has ignored the call.
    
    The next registered XContextMenuInterceptor should be notified.
    """

__all__ = ['ContextMenuInterceptorAction']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.property_set import PropertySet as PropertySet_b0e70ba2
from .x_legend import XLegend as XLegend_8cce09f3
from ..drawing.fill_properties import FillProperties as FillProperties_f1200da8
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .relative_position import RelativePosition as RelativePosition_fae10ddd
    from com.sun.star.chart2.LegendPosition import LegendPositionProto
    from com.sun.star.chart.ChartLegendExpansion import ChartLegendExpansionProto

class Legend(PropertySet_b0e70ba2, FillProperties_f1200da8, LineProperties_f13f0da9, XLegend_8cce09f3):
    """
    Service Class

    Describes a legend for a Diagram.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API Legend <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Legend.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.Legend'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AnchorPosition(self) -> LegendPositionProto:
        """
        Provides an automated position.
        """
        ...

    @abstractproperty
    def Expansion(self) -> ChartLegendExpansionProto:
        """
        Determines how the aspect ratio of the legend should roughly be.
        
        Set the Expansion to com.sun.star.chart.HIGH for a legend that is positioned on the right or left hand side. Use com.sun.star.chart.WIDE for a legend that is positioned on top or the bottom.
        """
        ...

    @abstractproperty
    def Overlay(self) -> bool:
        """
        Determines, whether the legend should overlay the chart.
        
        **since**
        
            LibreOffice 7.0
        """
        ...

    @abstractproperty
    def ReferencePageSize(self) -> Size_576707ef:
        """
        contains the size of the page at the time when properties were set (e.g.
        
        the CharHeight).
        
        This way it is possible to resize objects (like text) in the view without modifying the model.
        """
        ...

    @abstractproperty
    def RelativePosition(self) -> RelativePosition_fae10ddd:
        """
        The position is as a relative position on the page.
        
        If a relative position is given the legend is not automatically placed, but instead is placed relative on the page.
        
        If VOID, the legend position is solely determined by the AnchorPosition.
        """
        ...

    @abstractproperty
    def Show(self) -> bool:
        """
        Determines, whether the legend should be rendered by the view.
        """
        ...


__all__ = ['Legend']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.beans.PropertyState import PropertyStateProto

class PropertyState(Enum):
    """
    Enum Class


    See Also:
        `API PropertyState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyState'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.beans.PropertyState'

    AMBIGUOUS_VALUE = cast("PropertyStateProto", 'AMBIGUOUS_VALUE')
    """
    The value of the property is only a recommendation because there are multiple values for this property (e.g., from a multi selection).
    
    The PropertyAttribute field in the struct Property must contain the PropertyAttribute.MAYBEAMBIGUOUS flag. The property value must be available and of the specified type. If the Attribute field in the struct Property contains PropertyAttribute.MAYBEVOID, then the value may be void.
    """
    DEFAULT_VALUE = cast("PropertyStateProto", 'DEFAULT_VALUE')
    """
    The value of the property is available from a master (e.g., template).
    """
    DIRECT_VALUE = cast("PropertyStateProto", 'DIRECT_VALUE')
    """
    The value of the property is stored in the PropertySet itself.
    """

__all__ = ['PropertyState']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_extended_calendar import XExtendedCalendar as XExtendedCalendar_e5480ceb
if typing.TYPE_CHECKING:
    from .calendar2 import Calendar2 as Calendar2_88c10994
    from .calendar_item2 import CalendarItem2 as CalendarItem2_b38f0b23

class XCalendar3(XExtendedCalendar_e5480ceb):
    """
    This interface provides access to locale specific calendar systems.
    
    It is derived from com.sun.star.i18n.XExtendedCalendar and provides additional methods to obtain Calendar2 items that include the possessive genitive case month names and sequences of CalendarItem2 items...
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API XCalendar3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XCalendar3.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XCalendar3'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XCalendar3'

    @abstractmethod
    def getDays2(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        returns a sequence of CalendarItem2 describing the day names.
        """
        ...
    @abstractmethod
    def getGenitiveMonths2(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        returns a sequence of CalendarItem2 describing the genitive case month names.
        """
        ...
    @abstractmethod
    def getLoadedCalendar2(self) -> Calendar2_88c10994:
        """
        Get the currently loaded Calendar2.
        """
        ...
    @abstractmethod
    def getMonths2(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        returns a sequence of CalendarItem2 describing the month names.
        """
        ...
    @abstractmethod
    def getPartitiveMonths2(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        returns a sequence of CalendarItem2 describing the partitive case month names.
        """
        ...

__all__ = ['XCalendar3']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.image
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..document.x_events_supplier import XEventsSupplier as XEventsSupplier_ecd0e88

class ImageMapObject(XPropertySet_bc180bfa, XEventsSupplier_ecd0e88):
    """
    Service Class

    this is a base service for objects inside an image map.

    See Also:
        `API ImageMapObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1image_1_1ImageMapObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.image'
    __ooo_full_ns__: str = 'com.sun.star.image.ImageMapObject'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Description(self) -> str:
        """
        This is an optional description text for the link.
        """
        ...

    @abstractproperty
    def IsActive(self) -> bool:
        """
        If an object is not active, it is ignored when the user clicks on the ImageMap.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        Optionally, objects could be named.
        """
        ...

    @abstractproperty
    def Target(self) -> str:
        """
        This is the target frame.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        This is the URL for this object.
        """
        ...


__all__ = ['ImageMapObject']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rdf
from __future__ import annotations
from .x_resource import XResource as XResource_842709e4

class XBlankNode(XResource_842709e4):
    """
    represents a blank node that may occur in a RDF graph.
    
    Blank nodes are distinct, but have no URI; in other words, they are resources that are anonymous.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XBlankNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XBlankNode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rdf'
    __ooo_full_ns__: str = 'com.sun.star.rdf.XBlankNode'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rdf.XBlankNode'


__all__ = ['XBlankNode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tree
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_tree_data_model_listener import XTreeDataModelListener as XTreeDataModelListener_748210cb
    from .x_tree_node import XTreeNode as XTreeNode_baaf0ba0

class XTreeDataModel(XComponent_98dc0ab5):
    """
    An instance of this interface is used by the TreeControl to retrieve the hierarchical outline data that is displayed in the actual control.
    
    If you implement your own XTreeDataModel you need to notify registered XTreeDataModelListener if your model changes after the control is created. If this is not done correctly the TreeControl will not update the data properly.
    
    If you do not need your own model implementation, you can also use the MutableTreeDataModel.

    See Also:
        `API XTreeDataModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.XTreeDataModel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.tree.XTreeDataModel'

    @abstractmethod
    def addTreeDataModelListener(self, Listener: XTreeDataModelListener_748210cb) -> None:
        """
        Adds a listener for the TreeDataModelEvent posted after the tree changes.
        """
        ...
    @abstractmethod
    def getRoot(self) -> XTreeNode_baaf0ba0:
        """
        Returns the root of the tree.
        
        Returns null only if the tree has no nodes.
        """
        ...
    @abstractmethod
    def removeTreeDataModelListener(self, Listener: XTreeDataModelListener_748210cb) -> None:
        """
        Removes a listener previously added with addTreeDataModelListener().
        """
        ...

__all__ = ['XTreeDataModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class BreakType(metaclass=UnoEnumMeta, type_name="com.sun.star.style.BreakType", name_space="com.sun.star.style"):
        """Dynamically created class that represents ``com.sun.star.style.BreakType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.style.BreakType import COLUMN_AFTER as BREAK_TYPE_COLUMN_AFTER
        from com.sun.star.style.BreakType import COLUMN_BEFORE as BREAK_TYPE_COLUMN_BEFORE
        from com.sun.star.style.BreakType import COLUMN_BOTH as BREAK_TYPE_COLUMN_BOTH
        from com.sun.star.style.BreakType import NONE as BREAK_TYPE_NONE
        from com.sun.star.style.BreakType import PAGE_AFTER as BREAK_TYPE_PAGE_AFTER
        from com.sun.star.style.BreakType import PAGE_BEFORE as BREAK_TYPE_PAGE_BEFORE
        from com.sun.star.style.BreakType import PAGE_BOTH as BREAK_TYPE_PAGE_BOTH

        class BreakType(uno.Enum):
            """
            Enum Class


            See Also:
                `API BreakType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.style.BreakType', value)

            __ooo_ns__: str = 'com.sun.star.style'
            __ooo_full_ns__: str = 'com.sun.star.style.BreakType'
            __ooo_type_name__: str = 'enum'

            COLUMN_AFTER = BREAK_TYPE_COLUMN_AFTER
            """
            A column break is applied after the object to which it belongs.
            """
            COLUMN_BEFORE = BREAK_TYPE_COLUMN_BEFORE
            """
            A column break is applied before the object to which it belongs.
            """
            COLUMN_BOTH = BREAK_TYPE_COLUMN_BOTH
            """
            A column break is applied before and after the object to which it belongs.
            """
            NONE = BREAK_TYPE_NONE
            """
            No column or page break is applied.

            This value specifies that a location is not yet assigned.
            """
            PAGE_AFTER = BREAK_TYPE_PAGE_AFTER
            """
            A page break is applied after the object to which it belongs.
            """
            PAGE_BEFORE = BREAK_TYPE_PAGE_BEFORE
            """
            A page break is applied before the object to which it belongs.
            """
            PAGE_BOTH = BREAK_TYPE_PAGE_BOTH
            """
            A page break is applied before and after the object to which it belongs.
            """
    else:
        # keep document generators happy
        from ...lo.style.break_type import BreakType as BreakType


__all__ = ['BreakType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_property_bag import XPropertyBag as XPropertyBag_bbd00bd8

class PropertyBag(XPropertyBag_bbd00bd8):
    """
    Service Class

    Implementation of this service can keep any properties and is useful when an XPropertySet is to be used, for example, as parameters for a method call.
    
    Scripting engines might not be able to use such objects as normal property sets, giving direct access to the properties. In this case, use the methods like XPropertySet.getPropertyValue().

    See Also:
        `API PropertyBag <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1beans_1_1PropertyBag.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyBag'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self) -> None:
        """
        """
        ...
    @abstractmethod
    def createWithTypes(self, AllowedTypes: typing.Tuple[object, ...], AllowEmptyPropertyName: bool, AutomaticAddition: bool) -> None:
        """
        """
        ...

__all__ = ['PropertyBag']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment
from __future__ import annotations
import typing
from abc import abstractmethod, ABC

class XPackageInformationProvider(ABC):
    """
    Objects implementing this interface provide a URL to the root of an installed package.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XPackageInformationProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageInformationProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment'
    __ooo_full_ns__: str = 'com.sun.star.deployment.XPackageInformationProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.deployment.XPackageInformationProvider'

    @abstractmethod
    def getExtensionList(self) -> typing.Tuple[typing.Tuple[str, ...], ...]:
        """
        returns a list of all installed extension with their version.
        """
        ...
    @abstractmethod
    def getPackageLocation(self, extensionId: str) -> str:
        """
        get Package information for a specific extension.
        """
        ...
    @abstractmethod
    def isUpdateAvailable(self, extensionId: str) -> typing.Tuple[typing.Tuple[str, ...], ...]:
        """
        check if there are updates available for an extension.
        """
        ...

__all__ = ['XPackageInformationProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import uno
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XCipherContext(XInterface_8f010a43):
    """
    This interface allows to encrypt/decrypt data using the cipher context.
    
    The algorithm as well as encryption data are specified on object creation.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XCipherContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XCipherContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XCipherContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XCipherContext'

    @abstractmethod
    def convertWithCipherContext(self, aData: uno.ByteSequence) -> uno.ByteSequence:
        """
        encrypts/decrypts the data using the cipher.
        
        Please have in mind, the cipher object state might depend from the already encrypted/decrypted data ( it depends from the used algorithm ).
        
        Whether the object does encryption or decryption is specified by creation of the object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.DisposedException: ``DisposedException``
        """
        ...
    @abstractmethod
    def finalizeCipherContextAndDispose(self) -> uno.ByteSequence:
        """
        finalizes cipher and disposes context.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
        """
        ...

__all__ = ['XCipherContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class PasswordContainerInteractionHandler(XInteractionHandler_bf80e51):
    """
    Service Class

    An interaction request handler that uses the com.sun.star.task.PasswordContainer service to handle com.sun.star.ucb.AuthenticationRequest.
    
    If the password container contains credentials matching the authentication request, the service implementation selects the com.sun.star.ucb.XInteractionSupplyAuthentication continuation, that should be supplied with the interaction request.
    
    If the password container does not contain credentials matching the authentication request, the service implementation selects no continuation.
    
    **since**
    
        OOo 3.3

    See Also:
        `API PasswordContainerInteractionHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1task_1_1PasswordContainerInteractionHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.PasswordContainerInteractionHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['PasswordContainerInteractionHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.deployment.dependency_exception import DependencyException as DependencyException
with suppress(ImportError):
    from ...dyn.deployment.deployment_exception import DeploymentException as DeploymentException
with suppress(ImportError):
    from ...dyn.deployment.extension_manager import ExtensionManager as ExtensionManager
with suppress(ImportError):
    from ...dyn.deployment.extension_removed_exception import ExtensionRemovedException as ExtensionRemovedException
with suppress(ImportError):
    from ...dyn.deployment.install_exception import InstallException as InstallException
with suppress(ImportError):
    from ...dyn.deployment.invalid_removed_parameter_exception import InvalidRemovedParameterException as InvalidRemovedParameterException
with suppress(ImportError):
    from ...dyn.deployment.license_exception import LicenseException as LicenseException
with suppress(ImportError):
    from ...dyn.deployment.package_information_provider import PackageInformationProvider as PackageInformationProvider
with suppress(ImportError):
    from ...dyn.deployment.package_registry_backend import PackageRegistryBackend as PackageRegistryBackend
with suppress(ImportError):
    from ...dyn.deployment.platform_exception import PlatformException as PlatformException
with suppress(ImportError):
    from ...dyn.deployment.prerequisites import Prerequisites as Prerequisites
with suppress(ImportError):
    from ...dyn.deployment.prerequisites import PrerequisitesEnum as PrerequisitesEnum
with suppress(ImportError):
    from ...dyn.deployment.update_information_entry import UpdateInformationEntry as UpdateInformationEntry
with suppress(ImportError):
    from ...dyn.deployment.update_information_provider import UpdateInformationProvider as UpdateInformationProvider
with suppress(ImportError):
    from ...dyn.deployment.version_exception import VersionException as VersionException
with suppress(ImportError):
    from ...dyn.deployment.x_extension_manager import XExtensionManager as XExtensionManager
with suppress(ImportError):
    from ...dyn.deployment.x_package import XPackage as XPackage
with suppress(ImportError):
    from ...dyn.deployment.x_package_information_provider import XPackageInformationProvider as XPackageInformationProvider
with suppress(ImportError):
    from ...dyn.deployment.x_package_manager import XPackageManager as XPackageManager
with suppress(ImportError):
    from ...dyn.deployment.x_package_manager_factory import XPackageManagerFactory as XPackageManagerFactory
with suppress(ImportError):
    from ...dyn.deployment.x_package_registry import XPackageRegistry as XPackageRegistry
with suppress(ImportError):
    from ...dyn.deployment.x_package_type_info import XPackageTypeInfo as XPackageTypeInfo
with suppress(ImportError):
    from ...dyn.deployment.x_update_information_provider import XUpdateInformationProvider as XUpdateInformationProvider
with suppress(ImportError):
    from ...dyn.deployment.the_package_manager_factory import thePackageManagerFactory as thePackageManagerFactory



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
import typing
from abc import abstractproperty
from ..util.sort_descriptor import SortDescriptor as SortDescriptor_ca680c8d
if typing.TYPE_CHECKING:
    from ..util.sort_field import SortField as SortField_90080a52
    from com.sun.star.table.TableOrientation import TableOrientationProto

class TableSortDescriptor(SortDescriptor_ca680c8d):
    """
    Service Class

    contains properties which describe sorting of rows or columns in a table.
    
    It extends the general com.sun.star.util.SortDescriptor with table-specific properties.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API TableSortDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.TableSortDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SortFields(self) -> typing.Tuple[SortField_90080a52, ...]:
        """
        specifies the descriptions of the individual sort fields.
        """
        ...

    @abstractproperty
    def ContainsHeader(self) -> bool:
        """
        specifies whether the first row or column (depending on com.sun.star.util.SortDescriptor.SortColumns) is a header which should not be sorted.
        """
        ...

    @abstractproperty
    def MaxFieldCount(self) -> int:
        """
        contains the maximum number of sort fields the descriptor can hold.
        """
        ...

    @abstractproperty
    def Orientation(self) -> TableOrientationProto:
        """
        specifies the sorting orientation (sort rows or columns).
        
        Some implementations may not support sorting columns.
        """
        ...


__all__ = ['TableSortDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class CompositeOperation(object):
    """
    Const Class

    These constants determine how the primitive color is combined with the background.
    
    When performing these calculations, it is assumed that all color values are premultiplied with the corresponding alpha values (if no alpha is specified, 1.0 is assumed). Then, the following general compositing operation is performed:
    
    C = Ca * Fa + Cb * Fb
    
    where C is the result color, Ca and Cb are the input colors, premultiplied with alpha, and Fa and Fb are described for the different composite modes (wherein Aa and Ab denote source and destination alpha, respectively).
    
    **since**
    
        OOo 2.0

    See Also:
        `API CompositeOperation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1CompositeOperation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.CompositeOperation'
    __ooo_type_name__: str = 'const'

    CLEAR = 0
    """
    Clear the destination.
    
    Clear the destination area. The function values are: Fa = Fb = 0.
    """
    SOURCE = 1
    """
    Copy source as-is to the destination.
    
    Copy source as-is to the destination. The function values are: Fa = 1, Fb = 0.
    """
    DESTINATION = 2
    """
    Leave the destination as-is.
    
    Leave the destination as-is. The function values are: Fa = 0, Fb = 1.
    """
    OVER = 3
    """
    Copy the source over the destination.
    
    Copy the source over the destination. The function values are: Fa = 1, Fb = 1-Aa.
    """
    UNDER = 4
    """
    Copy the source under the destination.
    
    Copy the source under the destination. The function values are: Fa = 1-Ab, Fb = 1.
    """
    INSIDE = 5
    """
    Copy the source to the destination.
    
    Copy the source to the destination, but limited to where the destination is. The function values are: Fa = Ab, Fb = 0.
    """
    INSIDE_REVERSE = 6
    """
    Leave the destination as is.
    
    Leave the destination as is, but only where the source was. The function values are: Fa = 0, Fb = Aa.
    """
    OUTSIDE = 7
    """
    Copy the source to the destination.
    
    Copy the source to the destination, but limited to where the destination is not. The function values are: Fa = 1-Ab, Fb = 0.
    """
    OUTSIDE_REVERSE = 8
    """
    Leave the destination as is.
    
    Leave the destination as is, but only where the source has not been. The function values are: Fa = 0, Fb = 1-Aa.
    """
    ATOP = 9
    """
    Copy the source over the destination.
    
    Copy the source over the destination, but only where the destination is. Keep the destination. The function values are: Fa = Ab, Fb = 1-Aa.
    """
    ATOP_REVERSE = 10
    """
    Copy the destination over the source.
    
    Copy the destination over the source, but only where the source is. Keep the source. The function values are: Fa = 1-Ab, Fb = Aa.
    """
    XOR = 11
    """
    Combine source and destination by exclusive or.
    
    Take only the parts where either source or destination, but not both visible. The function values are: Fa = 1-Ab, Fb = 1-Aa.
    """
    ADD = 12
    """
    Add source and destination values.
    
    Simply add contributions of both source and destination. The resulting color values are limited to the permissible color range, and clipped to the maximal value, if exceeded. The function values are: Fa = 1, Fb = 1.
    """
    SATURATE = 13
    """
    Saturate source and destination.
    
    Saturate destination with source values. The function values are: Fa = min(1,(1-Ab)/Aa), Fb = 1
    """

__all__ = ['CompositeOperation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
from abc import abstractmethod
from .x_node import XNode as XNode_83fb09a5

class XCharacterData(XNode_83fb09a5):
    """

    See Also:
        `API XCharacterData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XCharacterData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XCharacterData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XCharacterData'

    @abstractmethod
    def appendData(self, arg: str) -> None:
        """
        Append the string to the end of the character data of the node.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def deleteData(self, offset: int, count: int) -> None:
        """
        Remove a range of 16-bit units from the node.
        
        Throws: DOMException - INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number of 16-bit units in data, or if the specified count is negative. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def getData(self) -> str:
        """
        Return the character data of the node that implements this interface.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly. DOMException - DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit in a DOMString variable on the implementation platform.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def getLength(self) -> int:
        """
        The number of 16-bit units that are available through data and the substringData method below.
        """
        ...
    @abstractmethod
    def insertData(self, offset: int, arg: str) -> None:
        """
        Insert a string at the specified 16-bit unit offset.
        
        Throws: DOMException - INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number of 16-bit units in data. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def replaceData(self, offset: int, count: int, arg: str) -> None:
        """
        Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        Throws; DOMException - INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number of 16-bit units in data, or if the specified count is negative. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setData(self, data: str) -> None:
        """
        Set the character data of the node that implements this interface.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly. DOMException - DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit in a DOMString variable on the implementation platform.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def subStringData(self, offset: int, count: int) -> str:
        """
        Extracts a range of data from the node.
        
        Throws: DOMException - INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number of 16-bit units in data, or if the specified count is negative. DOMSTRING_SIZE_ERR: Raised if the specified range of text does not fit into a DOMString.

        Raises:
            DOMException: ``DOMException``
        """
        ...

__all__ = ['XCharacterData']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TextContentAnchorType(metaclass=UnoEnumMeta, type_name="com.sun.star.text.TextContentAnchorType", name_space="com.sun.star.text"):
        """Dynamically created class that represents ``com.sun.star.text.TextContentAnchorType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.text.TextContentAnchorType import AS_CHARACTER as TEXT_CONTENT_ANCHOR_TYPE_AS_CHARACTER
        from com.sun.star.text.TextContentAnchorType import AT_CHARACTER as TEXT_CONTENT_ANCHOR_TYPE_AT_CHARACTER
        from com.sun.star.text.TextContentAnchorType import AT_FRAME as TEXT_CONTENT_ANCHOR_TYPE_AT_FRAME
        from com.sun.star.text.TextContentAnchorType import AT_PAGE as TEXT_CONTENT_ANCHOR_TYPE_AT_PAGE
        from com.sun.star.text.TextContentAnchorType import AT_PARAGRAPH as TEXT_CONTENT_ANCHOR_TYPE_AT_PARAGRAPH

        class TextContentAnchorType(uno.Enum):
            """
            Enum Class


            See Also:
                `API TextContentAnchorType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.text.TextContentAnchorType', value)

            __ooo_ns__: str = 'com.sun.star.text'
            __ooo_full_ns__: str = 'com.sun.star.text.TextContentAnchorType'
            __ooo_type_name__: str = 'enum'

            AS_CHARACTER = TEXT_CONTENT_ANCHOR_TYPE_AS_CHARACTER
            """
            The object is anchored instead of a character.
            """
            AT_CHARACTER = TEXT_CONTENT_ANCHOR_TYPE_AT_CHARACTER
            """
            The object is anchored to a character.
            """
            AT_FRAME = TEXT_CONTENT_ANCHOR_TYPE_AT_FRAME
            """
            The object is anchored to a text frame.
            """
            AT_PAGE = TEXT_CONTENT_ANCHOR_TYPE_AT_PAGE
            """
            The object is anchored to the page.
            """
            AT_PARAGRAPH = TEXT_CONTENT_ANCHOR_TYPE_AT_PARAGRAPH
            """
            The anchor of the object is set at the top left position of the paragraph.
            """
    else:
        # keep document generators happy
        from ...lo.text.text_content_anchor_type import TextContentAnchorType as TextContentAnchorType


__all__ = ['TextContentAnchorType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
import typing
from abc import abstractproperty
from ...awt.uno_control_image_control_model import UnoControlImageControlModel as UnoControlImageControlModel_7b36111c
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_image_producer_supplier import XImageProducerSupplier as XImageProducerSupplier_37df0f8f
if typing.TYPE_CHECKING:
    from com.sun.star.form.FormButtonType import FormButtonTypeProto

class ImageButton(UnoControlImageControlModel_7b36111c, FormControlModel_e2990d22, XImageProducerSupplier_37df0f8f):
    """
    Service Class

    This service specifies the control model for a clickable button which is represented by an image.
    
    The image to be displayed is determined by com.sun.star.awt.UnoControlImageControlModel.ImageURL property specifies the URL of an image to be displayed.

    See Also:
        `API ImageButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ImageButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.ImageButton'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ButtonType(self) -> FormButtonTypeProto:
        """
        describes the action to be executed by the button when pressed.
        """
        ...

    @abstractproperty
    def TargetFrame(self) -> str:
        """
        describes the frame, where to open the document specified by the TargetURL.
        
        This property is evaluated if the button is of type URL.
        
        As always, there is a number of target names which have a special meaning, and force a special com.sun.star.frame.Frame to be used.
        """
        ...

    @abstractproperty
    def TargetURL(self) -> str:
        """
        specifies the URL, which should be opened if the button was clicked.
        
        This property is evaluated if the button is of type URL.
        """
        ...


__all__ = ['ImageButton']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.resource
from __future__ import annotations
from abc import abstractmethod
from .x_string_resource_persistence import XStringResourcePersistence as XStringResourcePersistence_cabc130c

class XStringResourceWithLocation(XStringResourcePersistence_cabc130c):
    """
    Extends XStringResourcePersistence by methods to handle an associated location.

    See Also:
        `API XStringResourceWithLocation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceWithLocation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.resource'
    __ooo_full_ns__: str = 'com.sun.star.resource.XStringResourceWithLocation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.resource.XStringResourceWithLocation'

    @abstractmethod
    def setURL(self, URL: str) -> None:
        """
        Associates a location to the StringResourceWithStorage instance which is used on subsequent calls of store().
        
        This call has to be used carefully as it removes the location previously connected to the StringResourceWithStorage. It may force the implementation to reload data from the previous location before releasing it. The StringResourceManager will be modified after calling this method as the data isn't stored to the new location yet. storeAsURL() should be preferred as it directly stores the data to the new location and afterwards this location is in sync with the resource data.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def storeAsURL(self, URL: str) -> None:
        """
        Stores all string table data to a location and associates this location to this instance as if setLocation() was called with this location.
        
        The modified state will be unmodified after the call.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XStringResourceWithLocation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.view
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class SelectionType(metaclass=UnoEnumMeta, type_name="com.sun.star.view.SelectionType", name_space="com.sun.star.view"):
        """Dynamically created class that represents ``com.sun.star.view.SelectionType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.view.SelectionType import MULTI as SELECTION_TYPE_MULTI
        from com.sun.star.view.SelectionType import NONE as SELECTION_TYPE_NONE
        from com.sun.star.view.SelectionType import RANGE as SELECTION_TYPE_RANGE
        from com.sun.star.view.SelectionType import SINGLE as SELECTION_TYPE_SINGLE

        class SelectionType(uno.Enum):
            """
            Enum Class


            See Also:
                `API SelectionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1view.html#acffca3b33fddce63d3220bc7487e879d>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.view.SelectionType', value)

            __ooo_ns__: str = 'com.sun.star.view'
            __ooo_full_ns__: str = 'com.sun.star.view.SelectionType'
            __ooo_type_name__: str = 'enum'

            MULTI = SELECTION_TYPE_MULTI
            """
            The selection can contain zero or more objects.
            """
            NONE = SELECTION_TYPE_NONE
            """
            No selection is possible.

            The selection is always empty.
            """
            RANGE = SELECTION_TYPE_RANGE
            """
            The selection can contain zero or more objects.

            all selected objects must be part of a continues range
            """
            SINGLE = SELECTION_TYPE_SINGLE
            """
            The selection can only contain one or zero objects.
            """
    else:
        # keep document generators happy
        from ...lo.view.selection_type import SelectionType as SelectionType


__all__ = ['SelectionType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.form.control.check_box import CheckBox as CheckBox
with suppress(ImportError):
    from ....dyn.form.control.combo_box import ComboBox as ComboBox
with suppress(ImportError):
    from ....dyn.form.control.command_button import CommandButton as CommandButton
with suppress(ImportError):
    from ....dyn.form.control.currency_field import CurrencyField as CurrencyField
with suppress(ImportError):
    from ....dyn.form.control.date_field import DateField as DateField
with suppress(ImportError):
    from ....dyn.form.control.filter_control import FilterControl as FilterControl
with suppress(ImportError):
    from ....dyn.form.control.formatted_field import FormattedField as FormattedField
with suppress(ImportError):
    from ....dyn.form.control.grid_control import GridControl as GridControl
with suppress(ImportError):
    from ....dyn.form.control.group_box import GroupBox as GroupBox
with suppress(ImportError):
    from ....dyn.form.control.image_button import ImageButton as ImageButton
with suppress(ImportError):
    from ....dyn.form.control.image_control import ImageControl as ImageControl
with suppress(ImportError):
    from ....dyn.form.control.interaction_grid_control import InteractionGridControl as InteractionGridControl
with suppress(ImportError):
    from ....dyn.form.control.list_box import ListBox as ListBox
with suppress(ImportError):
    from ....dyn.form.control.navigation_tool_bar import NavigationToolBar as NavigationToolBar
with suppress(ImportError):
    from ....dyn.form.control.numeric_field import NumericField as NumericField
with suppress(ImportError):
    from ....dyn.form.control.pattern_field import PatternField as PatternField
with suppress(ImportError):
    from ....dyn.form.control.radio_button import RadioButton as RadioButton
with suppress(ImportError):
    from ....dyn.form.control.submit_button import SubmitButton as SubmitButton
with suppress(ImportError):
    from ....dyn.form.control.text_field import TextField as TextField
with suppress(ImportError):
    from ....dyn.form.control.time_field import TimeField as TimeField



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CommonFilePickerElementIds(metaclass=UnoConstMeta, type_name="com.sun.star.ui.dialogs.CommonFilePickerElementIds", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ui.dialogs.CommonFilePickerElementIds``"""
        pass

    class CommonFilePickerElementIdsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ui.dialogs.CommonFilePickerElementIds", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ui.dialogs.CommonFilePickerElementIds`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ui.dialogs import CommonFilePickerElementIds as CommonFilePickerElementIds
    else:
        # keep document generators happy
        from ....lo.ui.dialogs.common_file_picker_element_ids import CommonFilePickerElementIds as CommonFilePickerElementIds

    class CommonFilePickerElementIdsEnum(IntEnum):
        """
        Enum of Const Class CommonFilePickerElementIds

        These constants are used to specify common controls of a FilePicker dialog.
        
        **since**
        
            OOo 1.1.2
        """
        PUSHBUTTON_OK = CommonFilePickerElementIds.PUSHBUTTON_OK
        """
        The control id of the OK button.
        """
        PUSHBUTTON_CANCEL = CommonFilePickerElementIds.PUSHBUTTON_CANCEL
        """
        The control id of the Cancel button.
        """
        LISTBOX_FILTER = CommonFilePickerElementIds.LISTBOX_FILTER
        """
        The filter listbox of a FilePicker dialog.
        """
        CONTROL_FILEVIEW = CommonFilePickerElementIds.CONTROL_FILEVIEW
        """
        Is used to refer to the file view of the file picker.
        
        This view shows the list of all files/folders in the currently selected folder.
        """
        EDIT_FILEURL = CommonFilePickerElementIds.EDIT_FILEURL
        """
        Is used to refer to the edit line where a file or path can be entered by the user.
        """
        LISTBOX_FILTER_LABEL = CommonFilePickerElementIds.LISTBOX_FILTER_LABEL
        """
        The label of the filter listbox of a FilePicker dialog.
        
        **since**
        
            OOo 1.1.2
        """
        EDIT_FILEURL_LABEL = CommonFilePickerElementIds.EDIT_FILEURL_LABEL
        """
        The label of the file name listbox of a FilePicker dialog.
        
        **since**
        
            OOo 1.1.2
        """

__all__ = ['CommonFilePickerElementIds', 'CommonFilePickerElementIdsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.formula
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster_3d811522
from ..accessibility.x_accessible_text import XAccessibleText as XAccessibleText_5b77105b

class AccessibleFormulaView(XAccessible_1cbc0eb6, XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b, XAccessibleEventBroadcaster_3d811522, XAccessibleText_5b77105b):
    """
    Service Class

    The accessible view of a formula documents visual representation.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleFormulaView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1formula_1_1AccessibleFormulaView.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.formula'
    __ooo_full_ns__: str = 'com.sun.star.formula.AccessibleFormulaView'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleFormulaView']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FormulaMapGroup(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.FormulaMapGroup", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.FormulaMapGroup``"""
        pass

    class FormulaMapGroupEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.FormulaMapGroup", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.FormulaMapGroup`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import FormulaMapGroup as FormulaMapGroup
    else:
        # keep document generators happy
        from ...lo.sheet.formula_map_group import FormulaMapGroup as FormulaMapGroup

    class FormulaMapGroupEnum(IntEnum):
        """
        Enum of Const Class FormulaMapGroup

        Constants of bit masks used with XFormulaOpCodeMapper.getAvailableMappings() to specify for which group of symbols the mappings are to be obtained.
        
        If no bit is set, a sequence of special mappings is returned in the order that is defined by FormulaMapGroupSpecialOffset. Note that the special group and other groups are mutual exclusive.
        """
        SPECIAL = FormulaMapGroup.SPECIAL
        """
        Group of op-codes without a string symbol.
        """
        SEPARATORS = FormulaMapGroup.SEPARATORS
        """
        Separators and parentheses.
        """
        ARRAY_SEPARATORS = FormulaMapGroup.ARRAY_SEPARATORS
        """
        Separators and parentheses for constant arrays.
        """
        UNARY_OPERATORS = FormulaMapGroup.UNARY_OPERATORS
        """
        Unary operators.
        """
        BINARY_OPERATORS = FormulaMapGroup.BINARY_OPERATORS
        """
        Binary operators.
        """
        FUNCTIONS = FormulaMapGroup.FUNCTIONS
        """
        Functions.
        """
        ALL_EXCEPT_SPECIAL = FormulaMapGroup.ALL_EXCEPT_SPECIAL
        """
        All groups except SPECIAL.
        """

__all__ = ['FormulaMapGroup', 'FormulaMapGroupEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.drawing.RectanglePoint import RectanglePointProto

class RectanglePoint(Enum):
    """
    Enum Class


    See Also:
        `API RectanglePoint <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.RectanglePoint'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.RectanglePoint'

    LEFT_BOTTOM = cast("RectanglePointProto", 'LEFT_BOTTOM')
    """
    specify to the point on the bottom of the left side from the rectangle.
    """
    LEFT_MIDDLE = cast("RectanglePointProto", 'LEFT_MIDDLE')
    """
    specify to the point on the middle of the left side from the rectangle.
    """
    LEFT_TOP = cast("RectanglePointProto", 'LEFT_TOP')
    """
    specify to the point on the left side from the top of the rectangle.
    """
    MIDDLE_BOTTOM = cast("RectanglePointProto", 'MIDDLE_BOTTOM')
    """
    specify to the point on the middle of the bottom from the rectangle.
    """
    MIDDLE_MIDDLE = cast("RectanglePointProto", 'MIDDLE_MIDDLE')
    """
    specify to the point on the center from the rectangle.
    """
    MIDDLE_TOP = cast("RectanglePointProto", 'MIDDLE_TOP')
    """
    specify to the point on the middle of the top from the rectangle.
    """
    RIGHT_BOTTOM = cast("RectanglePointProto", 'RIGHT_BOTTOM')
    """
    specify to the point on the bottom of the right side from the rectangle.
    """
    RIGHT_MIDDLE = cast("RectanglePointProto", 'RIGHT_MIDDLE')
    """
    specify to the point on the middle of the right side from the rectangle.
    """
    RIGHT_TOP = cast("RectanglePointProto", 'RIGHT_TOP')
    """
    specify to the point on the right side from the top of the rectangle.
    """

__all__ = ['RectanglePoint']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xforms
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ..container.x_set import XSet as XSet_90c40a4f
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51
    from .x_data_type_repository import XDataTypeRepository as XDataTypeRepository_2bbb0f5b
    from .x_submission import XSubmission as XSubmission_bf230c2b
    from ..xml.dom.x_document import XDocument as XDocument_aebc0b5e

class XModel(ABC):
    """
    represent an XForms model

    See Also:
        `API XModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xforms_1_1XModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xforms'
    __ooo_full_ns__: str = 'com.sun.star.xforms.XModel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xforms.XModel'

    @abstractmethod
    def cloneBinding(self, binding: XPropertySet_bc180bfa) -> XPropertySet_bc180bfa:
        """
        clone an arbitrary binding element for this model; still needs
        
        The returned binding still needs to be inserted into the bindings container.
        """
        ...
    @abstractmethod
    def cloneSubmission(self, submission: XPropertySet_bc180bfa) -> XSubmission_bf230c2b:
        """
        clone an arbitrary submission element for this model
        
        The returned submission element still needs to be inserted into the submission container.
        """
        ...
    @abstractmethod
    def createBinding(self) -> XPropertySet_bc180bfa:
        """
        create a binding element for this model
        
        The returned binding still needs to be inserted into the bindings container.
        """
        ...
    @abstractmethod
    def createSubmission(self) -> XSubmission_bf230c2b:
        """
        create a submission element for this model
        
        The returned submission element still needs to be inserted into the submission container.
        """
        ...
    @abstractmethod
    def getBinding(self, id: str) -> XPropertySet_bc180bfa:
        """
        get a binding with a certain ID
        
        This is a convenience method: the same result can also be obtained through getBindings()
        """
        ...
    @abstractmethod
    def getBindings(self) -> XSet_90c40a4f:
        """
        get a container containing all bindings; also supports XNameAccess
        """
        ...
    @abstractmethod
    def getDataTypeRepository(self) -> XDataTypeRepository_2bbb0f5b:
        """
        provides management access to the XSD data types associated with the model
        """
        ...
    @abstractmethod
    def getDefaultInstance(self) -> XDocument_aebc0b5e:
        """
        get the default instance for this model
        """
        ...
    @abstractmethod
    def getID(self) -> str:
        """
        get the XForms model ID
        """
        ...
    @abstractmethod
    def getInstanceDocument(self, id: str) -> XDocument_aebc0b5e:
        """
        retrieves the instance with the given id
        """
        ...
    @abstractmethod
    def getInstances(self) -> XSet_90c40a4f:
        """
        gets container containing all instances;
        
        The elements of the set are arrays of com.sun.star.beans.PropertyValues, containing the ID, the URL, and the instance itself.
        """
        ...
    @abstractmethod
    def getSubmission(self, id: str) -> XSubmission_bf230c2b:
        """
        get a submission with a certain ID.
        
        This is a convenience method: the same result can also be obtained through getSubmissions().
        """
        ...
    @abstractmethod
    def getSubmissions(self) -> XSet_90c40a4f:
        """
        get container containing all submissions; also supports XNameAccess
        """
        ...
    @abstractmethod
    def initialize(self) -> None:
        """
        initialize the model
        """
        ...
    @abstractmethod
    def rebuild(self) -> None:
        """
        rebuild the model
        """
        ...
    @abstractmethod
    def recalculate(self) -> None:
        """
        re-evaluate all calculate attributes
        """
        ...
    @abstractmethod
    def refresh(self) -> None:
        """
        refresh the model
        """
        ...
    @abstractmethod
    def revalidate(self) -> None:
        """
        re-evaluate all validity attributes
        """
        ...
    @abstractmethod
    def setID(self, id: str) -> None:
        """
        set the XForms model ID
        """
        ...
    @abstractmethod
    def submit(self, id: str) -> None:
        """
        submit form through given submission id
        
        This is a convenience method. Calling it is equivalent to calling getSubmission()( id ).submit().

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def submitWithInteraction(self, id: str, aHandler: XInteractionHandler_bf80e51) -> None:
        """
        submit form through given submission id
        
        This is a convenience method. Calling it is equivalent to calling getSubmission()( id, handler ).submit().

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rdf
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35
    from .x_blank_node import XBlankNode as XBlankNode_8cf40a0a
    from .x_named_graph import XNamedGraph as XNamedGraph_97680a73
    from .x_node import XNode as XNode_5ee40822
    from .x_query_select_result import XQuerySelectResult as XQuerySelectResult_eebb0d91
    from .x_resource import XResource as XResource_842709e4
    from .xuri import XURI as XURI_5682078c

class XRepository(ABC):
    """
    provides access to a set of named RDF graphs.
    
    A repository for storing information according to the data model of the Resource Description Framework. This interface may be used e.g. for repositories that correspond to a loaded ODF document, or for repositories that are backed by some kind of database.
    
    The RDF triples are stored as a set of named RDF graphs. Importing and exporting files in the RDF/XML format is supported. Support for other file formats is optional. Support for querying the repository with the SPARQL query language is provided.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XRepository <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XRepository.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rdf'
    __ooo_full_ns__: str = 'com.sun.star.rdf.XRepository'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rdf.XRepository'

    @abstractmethod
    def createBlankNode(self) -> XBlankNode_8cf40a0a:
        """
        creates a fresh unique blank node.
        """
        ...
    @abstractmethod
    def createGraph(self, GraphName: XURI_5682078c) -> XNamedGraph_97680a73:
        """
        creates a graph with the given name.
        
        The name must be unique within the repository.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def destroyGraph(self, GraphName: XURI_5682078c) -> None:
        """
        destroys the graph with the given name, and removes it from the repository.
        
        This invalidates any instances of XNamedGraph for the argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def exportGraph(self, Format: int, OutStream: XOutputStream_a4e00b35, GraphName: XURI_5682078c, BaseURI: XURI_5682078c) -> None:
        """
        exports a named graph from the repository.
        
        Implementations must support RDF/XML format. Support for other RDF formats is optional. If the format is not supported by the implementation, an com.sun.star.datatransfer.UnsupportedFlavorException is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.datatransfer.UnsupportedFlavorException: ``UnsupportedFlavorException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def getGraph(self, GraphName: XURI_5682078c) -> XNamedGraph_97680a73:
        """
        gets a graph by its name.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def getGraphNames(self) -> typing.Tuple[XURI_5682078c, ...]:
        """
        gets the names of all the graphs in the repository.

        Raises:
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def getStatements(self, Subject: XResource_842709e4, Predicate: XURI_5682078c, Object: XNode_5ee40822) -> XEnumeration_f2180daa:
        """
        gets matching RDF statements from the repository.
        
        Any parameter may be NULL, which acts as a wildcard. For example, to get all statements about myURI: getStatements(myURI, null, null)

        Raises:
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def importGraph(self, Format: int, InStream: XInputStream_98d40ab4, GraphName: XURI_5682078c, BaseURI: XURI_5682078c) -> XNamedGraph_97680a73:
        """
        imports a named graph into the repository.
        
        Implementations must support RDF/XML format. Support for other RDF formats is optional. If the format is not supported by the implementation, an com.sun.star.datatransfer.UnsupportedFlavorException is raised. If the format requires use of a BaseURI, but none is given, an com.sun.star.lang.IllegalArgumentException is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.datatransfer.UnsupportedFlavorException: ``UnsupportedFlavorException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            ParseException: ``ParseException``
            RepositoryException: ``RepositoryException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def queryAsk(self, Query: str) -> bool:
        """
        executes a SPARQL \"ASK\" query.
        
        This method runs a SPARQL query that computes a boolean, i.e., a query beginning with \"ASK\".

        Raises:
            QueryException: ``QueryException``
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def queryConstruct(self, Query: str) -> XEnumeration_f2180daa:
        """
        executes a SPARQL \"CONSTRUCT\" query.
        
        This method runs a SPARQL query that constructs a result graph, i.e., a query beginning with \"CONSTRUCT\".

        Raises:
            QueryException: ``QueryException``
            RepositoryException: ``RepositoryException``
        """
        ...
    @abstractmethod
    def querySelect(self, Query: str) -> XQuerySelectResult_eebb0d91:
        """
        executes a SPARQL \"SELECT\" query.
        
        This method runs a SPARQL query that returns a list of variable bindings, i.e., a query beginning with \"SELECT\". The result is basically a (rectangular) table with labeled columns, where individual cells may be NULL.

        Raises:
            QueryException: ``QueryException``
            RepositoryException: ``RepositoryException``
        """
        ...

__all__ = ['XRepository']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.sdbcx.check_option import CheckOption as CheckOption
with suppress(ImportError):
    from ...dyn.sdbcx.check_option import CheckOptionEnum as CheckOptionEnum
with suppress(ImportError):
    from ...dyn.sdbcx.column import Column as Column
with suppress(ImportError):
    from ...dyn.sdbcx.column_descriptor import ColumnDescriptor as ColumnDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.compare_bookmark import CompareBookmark as CompareBookmark
with suppress(ImportError):
    from ...dyn.sdbcx.compare_bookmark import CompareBookmarkEnum as CompareBookmarkEnum
with suppress(ImportError):
    from ...dyn.sdbcx.container import Container as Container
with suppress(ImportError):
    from ...dyn.sdbcx.database_definition import DatabaseDefinition as DatabaseDefinition
with suppress(ImportError):
    from ...dyn.sdbcx.descriptor import Descriptor as Descriptor
with suppress(ImportError):
    from ...dyn.sdbcx.driver import Driver as Driver
with suppress(ImportError):
    from ...dyn.sdbcx.group import Group as Group
with suppress(ImportError):
    from ...dyn.sdbcx.group_descriptor import GroupDescriptor as GroupDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.index import Index as Index
with suppress(ImportError):
    from ...dyn.sdbcx.index_column import IndexColumn as IndexColumn
with suppress(ImportError):
    from ...dyn.sdbcx.index_column_descriptor import IndexColumnDescriptor as IndexColumnDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.index_descriptor import IndexDescriptor as IndexDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.key import Key as Key
with suppress(ImportError):
    from ...dyn.sdbcx.key_column import KeyColumn as KeyColumn
with suppress(ImportError):
    from ...dyn.sdbcx.key_column_descriptor import KeyColumnDescriptor as KeyColumnDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.key_descriptor import KeyDescriptor as KeyDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.key_type import KeyType as KeyType
with suppress(ImportError):
    from ...dyn.sdbcx.key_type import KeyTypeEnum as KeyTypeEnum
with suppress(ImportError):
    from ...dyn.sdbcx.prepared_statement import PreparedStatement as PreparedStatement
with suppress(ImportError):
    from ...dyn.sdbcx.privilege import Privilege as Privilege
with suppress(ImportError):
    from ...dyn.sdbcx.privilege import PrivilegeEnum as PrivilegeEnum
with suppress(ImportError):
    from ...dyn.sdbcx.privilege_object import PrivilegeObject as PrivilegeObject
with suppress(ImportError):
    from ...dyn.sdbcx.privilege_object import PrivilegeObjectEnum as PrivilegeObjectEnum
with suppress(ImportError):
    from ...dyn.sdbcx.reference_column import ReferenceColumn as ReferenceColumn
with suppress(ImportError):
    from ...dyn.sdbcx.result_set import ResultSet as ResultSet
with suppress(ImportError):
    from ...dyn.sdbcx.statement import Statement as Statement
with suppress(ImportError):
    from ...dyn.sdbcx.table import Table as Table
with suppress(ImportError):
    from ...dyn.sdbcx.table_descriptor import TableDescriptor as TableDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.user import User as User
with suppress(ImportError):
    from ...dyn.sdbcx.user_descriptor import UserDescriptor as UserDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.view import View as View
with suppress(ImportError):
    from ...dyn.sdbcx.view_descriptor import ViewDescriptor as ViewDescriptor
with suppress(ImportError):
    from ...dyn.sdbcx.x_alter_table import XAlterTable as XAlterTable
with suppress(ImportError):
    from ...dyn.sdbcx.x_alter_view import XAlterView as XAlterView
with suppress(ImportError):
    from ...dyn.sdbcx.x_append import XAppend as XAppend
with suppress(ImportError):
    from ...dyn.sdbcx.x_authorizable import XAuthorizable as XAuthorizable
with suppress(ImportError):
    from ...dyn.sdbcx.x_columns_supplier import XColumnsSupplier as XColumnsSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_create_catalog import XCreateCatalog as XCreateCatalog
with suppress(ImportError):
    from ...dyn.sdbcx.x_data_definition_supplier import XDataDefinitionSupplier as XDataDefinitionSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory
with suppress(ImportError):
    from ...dyn.sdbcx.x_delete_rows import XDeleteRows as XDeleteRows
with suppress(ImportError):
    from ...dyn.sdbcx.x_drop import XDrop as XDrop
with suppress(ImportError):
    from ...dyn.sdbcx.x_drop_catalog import XDropCatalog as XDropCatalog
with suppress(ImportError):
    from ...dyn.sdbcx.x_groups_supplier import XGroupsSupplier as XGroupsSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_indexes_supplier import XIndexesSupplier as XIndexesSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_keys_supplier import XKeysSupplier as XKeysSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_rename import XRename as XRename
with suppress(ImportError):
    from ...dyn.sdbcx.x_row_locate import XRowLocate as XRowLocate
with suppress(ImportError):
    from ...dyn.sdbcx.x_tables_supplier import XTablesSupplier as XTablesSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_user import XUser as XUser
with suppress(ImportError):
    from ...dyn.sdbcx.x_users_supplier import XUsersSupplier as XUsersSupplier
with suppress(ImportError):
    from ...dyn.sdbcx.x_views_supplier import XViewsSupplier as XViewsSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Date(object):
    """
    Struct Class

    represents a date value.
    
    The time zone is unknown.

    See Also:
        `API Date <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1Date.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.Date'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.Date'
    """Literal Constant ``com.sun.star.util.Date``"""

    def __init__(self, Day: typing.Optional[int] = 0, Month: typing.Optional[int] = 0, Year: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Day (int, optional): Day value.
            Month (int, optional): Month value.
            Year (int, optional): Year value.
        """
        super().__init__()

        if isinstance(Day, Date):
            oth: Date = Day
            self.Day = oth.Day
            self.Month = oth.Month
            self.Year = oth.Year
            return

        kargs = {
            "Day": Day,
            "Month": Month,
            "Year": Year,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._day = kwargs["Day"]
        self._month = kwargs["Month"]
        self._year = kwargs["Year"]


    @property
    def Day(self) -> int:
        """
        contains the day of month (1-31 or 0 for a void date).
        """
        return self._day

    @Day.setter
    def Day(self, value: int) -> None:
        self._day = value

    @property
    def Month(self) -> int:
        """
        contains the month of year (1-12 or 0 for a void date).
        """
        return self._month

    @Month.setter
    def Month(self, value: int) -> None:
        self._month = value

    @property
    def Year(self) -> int:
        """
        contains the year.
        """
        return self._year

    @Year.setter
    def Year(self, value: int) -> None:
        self._year = value


__all__ = ['Date']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_idl_array import XIdlArray as XIdlArray_d65d0ca3
    from .x_idl_field import XIdlField as XIdlField_d62c0c88
    from .x_idl_method import XIdlMethod as XIdlMethod_e3740d05
    from ..uno.uik import Uik as Uik_4fac0783
    from com.sun.star.uno.TypeClass import TypeClassProto

class XIdlClass(XInterface_8f010a43):
    """
    Provides information reflecting a UNO type.

    See Also:
        `API XIdlClass <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlClass.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlClass'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlClass'

    @abstractmethod
    def createObject(self, obj: object) -> None:
        """
        This method creates instances of the reflected type.

        * ``obj`` is an out direction argument.
        """
        ...
    @abstractmethod
    def equals(self, Type: XIdlClass) -> bool:
        """
        Tests whether two reflecting objects reflect the same type.
        """
        ...
    @abstractmethod
    def getArray(self) -> XIdlArray_d65d0ca3:
        """
        If the reflected type is an array, then you get a XIdlArray interface to modify instances of the array type.
        
        If the reflected type is not an array, then a null-reference is returned.
        """
        ...
    @abstractmethod
    def getClass(self, aName: str) -> XIdlClass:
        """
        Deprecated.
        
        Do not call.
        """
        ...
    @abstractmethod
    def getClasses(self) -> typing.Tuple[XIdlClass, ...]:
        """
        Deprecated.
        
        Do not call.
        """
        ...
    @abstractmethod
    def getComponentType(self) -> XIdlClass:
        """
        If the reflected type is an array or sequence, then this method returns a XIdlClass interface reflecting the element.
        """
        ...
    @abstractmethod
    def getField(self, aName: str) -> XIdlField_d62c0c88:
        """
        If the reflected type is an interface, struct or union, then you get a XIdlField interface reflecting the demanded field (/interface attribute) by name.
        
        If the reflected type is not an interface, struct or union or the interface, struct or union does not have a field (/interface attribute) with the demanded name, then a null-reference is returned.
        """
        ...
    @abstractmethod
    def getFields(self) -> typing.Tuple[XIdlField_d62c0c88, ...]:
        """
        If the reflected type is an interface, struct or union, then you get a sequence of XIdlField interfaces reflecting all fields (/interface attributes).
        
        This also includes all inherited fields (/interface attributes) of the interface, struct of union. If the reflected type is not an interface, struct or union or the interface, struct or union does not have any field (/interface attribute), then an empty sequence is returned.
        """
        ...
    @abstractmethod
    def getInterfaces(self) -> typing.Tuple[XIdlClass, ...]:
        """
        Deprecated.
        
        Do not call.
        """
        ...
    @abstractmethod
    def getMethod(self, aName: str) -> XIdlMethod_e3740d05:
        """
        If the reflected type is an interface, then you get a XIdlMethod interface reflecting the demanded method by name.
        
        If the reflected type is not an interface or the interface does not have a method with the demanded name (including inherited methods), then a null-reference is returned.
        """
        ...
    @abstractmethod
    def getMethods(self) -> typing.Tuple[XIdlMethod_e3740d05, ...]:
        """
        If the reflected type is an interface, then you get a sequence of XIdlMethod interfaces reflecting all methods of the interface.
        
        This also includes the inherited methods of the interface. If the reflected type is not an interface or the interface does not have any methods, then a null-reference is returned.
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        Returns the fully-qualified name of the reflected type.
        """
        ...
    @abstractmethod
    def getSuperclasses(self) -> typing.Tuple[XIdlClass, ...]:
        """
        If the reflected type is an interface, then the returned sequence of XIdlClass reflect the base interfaces.
        
        If the reflected type is not an interface or an interface that is not derived from another, then an empty sequence is returned.
        """
        ...
    @abstractmethod
    def getTypeClass(self) -> TypeClassProto:
        """
        Returns the com.sun.star.uno.TypeClass of the reflected type.
        """
        ...
    @abstractmethod
    def getUik(self) -> Uik_4fac0783:
        """
        Deprecated.
        
        Do not call.
        """
        ...
    @abstractmethod
    def isAssignableFrom(self, xType: XIdlClass) -> bool:
        """
        Tests whether values of this reflected type are assignable from values of a second one (xType).
        """
        ...

__all__ = ['XIdlClass']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_stream_listener import XStreamListener as XStreamListener_baf80bea

class XActiveDataControl(XInterface_8f010a43):
    """
    makes it possible to control an active data source.
    
    This interface should be supported by objects which implement XActiveDataSource or XActiveDataSink.

    See Also:
        `API XActiveDataControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XActiveDataControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XActiveDataControl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XActiveDataControl'

    @abstractmethod
    def addListener(self, aListener: XStreamListener_baf80bea) -> None:
        """
        registers an object to receive events from this data source.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def removeListener(self, aListener: XStreamListener_baf80bea) -> None:
        """
        unregisters an object to receive events from this data source.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def start(self) -> None:
        """
        starts I/O.
        
        Either XActiveDataControl.setInputStream() or XActiveDataControl.setOutputStream() must be called beforehand.
        
        This method does not block the thread, so reading is generally not finished when the method returns.
        """
        ...
    @abstractmethod
    def terminate(self) -> None:
        """
        does a weak abort.
        
        It closes all connected resources and calls XInputStream.close() or XOutputStream.close() and fires the XStreamListener.terminated()-event.
        """
        ...

__all__ = ['XActiveDataControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XDragSourceContext(XInterface_8f010a43):
    """
    The drag source context class is responsible for managing the initiator side of the Drag and Drop protocol.
    
    In particular, it is responsible for managing event notifications to the DragSourceListener and providing the Transferable state to enable the data transfer.
    
    An instance of this class is created as a result of the method XDragSource.startDrag() being successfully invoked. This instance is responsible for tracking the state of the operation on behalf of the drag source and dispatching state changes to the drag source listener.

    See Also:
        `API XDragSourceContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XDragSourceContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XDragSourceContext'

    @abstractmethod
    def getCurrentCursor(self) -> int:
        """
        Get the identifier of the currently used cursor.
        """
        ...
    @abstractmethod
    def setCursor(self, cursorId: int) -> None:
        """
        This method sets the current drag cursor.
        
        This method should only be called to set another cursor than the default one for drag action currently selected by the user.
        
        Invalid cursor identifiers will be ignored.
        """
        ...
    @abstractmethod
    def setImage(self, imageId: int) -> None:
        """
        This method sets the current drag image.
        """
        ...
    @abstractmethod
    def transferablesFlavorsChanged(self) -> None:
        """
        This method notifies the context that the com.sun.star.datatransfer.DataFlavor types of the transferable object have changed.
        """
        ...

__all__ = ['XDragSourceContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.system
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSimpleMailMessage(XInterface_8f010a43):
    """
    This interface lets a client set or get the information of a simple mail message.

    See Also:
        `API XSimpleMailMessage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailMessage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.system'
    __ooo_full_ns__: str = 'com.sun.star.system.XSimpleMailMessage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.system.XSimpleMailMessage'

    @abstractmethod
    def getAttachement(self) -> typing.Tuple[str, ...]:
        """
        To get the attachment of a simple mail message.
        """
        ...
    @abstractmethod
    def getBccRecipient(self) -> typing.Tuple[str, ...]:
        """
        To get the BCC recipients of a simple mail message.
        
        If no BCC recipients have been specified an empty sequence will be returned.
        """
        ...
    @abstractmethod
    def getCcRecipient(self) -> typing.Tuple[str, ...]:
        """
        To get the cc recipients of a simple mail message.
        
        If no cc recipients have been specified an empty sequence will be returned.
        """
        ...
    @abstractmethod
    def getOriginator(self) -> str:
        """
        To get the email address of the originator of a simple mail message.
        
        If no originator has been specified an empty string will be returned.
        """
        ...
    @abstractmethod
    def getRecipient(self) -> str:
        """
        To get the recipient of the simple mail message.
        """
        ...
    @abstractmethod
    def getSubject(self) -> str:
        """
        To get the subject of a simple mail message.
        
        If no subject has been specified an empty string will be returned.
        """
        ...
    @abstractmethod
    def setAttachement(self, aAttachement: typing.Tuple[str, ...]) -> None:
        """
        To set an attachment of a simple mail message.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setBccRecipient(self, aBccRecipient: typing.Tuple[str, ...]) -> None:
        """
        To set the BCC recipient of a simple mail message.
        """
        ...
    @abstractmethod
    def setCcRecipient(self, aCcRecipient: typing.Tuple[str, ...]) -> None:
        """
        To set the cc recipients of a simple mail message.
        
        The method does not check if the given addresses are valid. An empty sequence means there are no cc recipients.
        """
        ...
    @abstractmethod
    def setOriginator(self, aOriginator: str) -> None:
        """
        To set the email address of the originator of a simple mail message.
        """
        ...
    @abstractmethod
    def setRecipient(self, aRecipient: str) -> None:
        """
        To set the recipient of the simple mail message.
        """
        ...
    @abstractmethod
    def setSubject(self, aSubject: str) -> None:
        """
        To set the subject of a simple mail message.
        """
        ...

__all__ = ['XSimpleMailMessage']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.drawing.MeasureTextVertPos import MeasureTextVertPosProto

class MeasureTextVertPos(Enum):
    """
    Enum Class


    See Also:
        `API MeasureTextVertPos <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#afb97f6590316423181878e8f5f79f087>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.MeasureTextVertPos'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.MeasureTextVertPos'

    AUTO = cast("MeasureTextVertPosProto", 'AUTO')
    """
    the connection point is chosen automatically,
    
    Set this to have the application select the best horizontal position for the text.
    """
    BREAKEDLINE = cast("MeasureTextVertPosProto", 'BREAKEDLINE')
    """
    """
    CENTERED = cast("MeasureTextVertPosProto", 'CENTERED')
    """
    The text is positioned at the center.
    
    The text is positioned over the main line.
    """
    EAST = cast("MeasureTextVertPosProto", 'EAST')
    """
    """
    WEST = cast("MeasureTextVertPosProto", 'WEST')
    """
    """

__all__ = ['MeasureTextVertPos']

